@@ -12,8 +12,6 @@
 
 from djvu.const import *
 from djvu.sexpr import *
-import unittest
-import doctest
 
 class TextZonesTest:
     r'''
@@ -60,14 +58,4 @@ class TextZonesTest:
     [[0, -1, -1, -1, -1, -1, -1], [1, 0, -1, -1, -1, -1, -1], [1, 1, 0, -1, -1, -1, -1], [1, 1, 1, 0, -1, -1, -1], [1, 1, 1, 1, 0, -1, -1], [1, 1, 1, 1, 1, 0, -1], [1, 1, 1, 1, 1, 1, 0]]
     '''
 
-if __name__ == '__main__':
-    import os, sys
-    os.chdir(sys.path[0])
-    del os, sys
-    doctest.testmod(verbose = False)
-    doctest.master.summarize(verbose = True)
-    print
-    unittest.main()
-    print; print
-
 # vim:ts=4 sw=4 et
